# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`thanos`](#thanos): This module manages Thanos
* [`thanos::compact`](#thanoscompact): This class manages compact service
* [`thanos::config`](#thanosconfig): This class manages configuration files
* [`thanos::install`](#thanosinstall): This class install Thanos requirements and binaries.
* [`thanos::query`](#thanosquery): This class manages query service
* [`thanos::query_frontend`](#thanosquery_frontend): This class manages query frontend service
* [`thanos::receive`](#thanosreceive): This class manages receiver service
* [`thanos::rule`](#thanosrule): This class manages rule service
* [`thanos::sidecar`](#thanossidecar): This class manages sidecar service
* [`thanos::store`](#thanosstore): This class manages store service
* [`thanos::tools::bucket_web`](#thanostoolsbucket_web): This class manages bucket web interface service

### Defined types

* [`thanos::config::index_cache`](#thanosconfigindex_cache): Manage Index cache configuration file.
* [`thanos::config::storage`](#thanosconfigstorage): Manage Storage configuration file.
* [`thanos::config::tracing`](#thanosconfigtracing): Manage Tracing configuration file.
* [`thanos::resources::service`](#thanosresourcesservice): This defined type create component's service.

### Data types

* [`Thanos::Index_cache_type`](#thanosindex_cache_type): Thanos index cache type
* [`Thanos::Log_level`](#thanoslog_level): Thanos Log Level type
* [`Thanos::Storage_type`](#thanosstorage_type): Thanos Storage type
* [`Thanos::Tracing_type`](#thanostracing_type): Thanos Tracing type

## Classes

### <a name="thanos"></a>`thanos`

Init class of Thanos module. It can installes Thanos binaries and manages components as single Service.

#### Examples

##### 

```puppet
include thanos
```

#### Parameters

The following parameters are available in the `thanos` class:

* [`version`](#version)
* [`os`](#os)
* [`manage_sidecar`](#manage_sidecar)
* [`manage_query`](#manage_query)
* [`manage_query_frontend`](#manage_query_frontend)
* [`manage_rule`](#manage_rule)
* [`manage_store`](#manage_store)
* [`manage_compact`](#manage_compact)
* [`manage_receive`](#manage_receive)
* [`manage_tools_bucket_web`](#manage_tools_bucket_web)
* [`install_method`](#install_method)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)
* [`base_url`](#base_url)
* [`download_extension`](#download_extension)
* [`download_url`](#download_url)
* [`base_dir`](#base_dir)
* [`bin_dir`](#bin_dir)
* [`config_dir`](#config_dir)
* [`purge_config_dir`](#purge_config_dir)
* [`tsdb_path`](#tsdb_path)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`user`](#user)
* [`group`](#group)
* [`usershell`](#usershell)
* [`extra_groups`](#extra_groups)
* [`extract_command`](#extract_command)
* [`manage_storage_config`](#manage_storage_config)
* [`storage_config_file`](#storage_config_file)
* [`storage_config`](#storage_config)
* [`manage_tracing_config`](#manage_tracing_config)
* [`tracing_config_file`](#tracing_config_file)
* [`tracing_config`](#tracing_config)
* [`manage_index_cache_config`](#manage_index_cache_config)
* [`index_cache_config_file`](#index_cache_config_file)
* [`index_cache_config`](#index_cache_config)

##### <a name="version"></a>`version`

Data type: `Pattern[/\d+\.\d+\.\d+/]`

Thanos release. See https://github.com/thanos-io/thanos/releases

##### <a name="os"></a>`os`

Data type: `String`

Operating system.

Default value: `downcase($facts['kernel'])`

##### <a name="manage_sidecar"></a>`manage_sidecar`

Data type: `Boolean`

Whether to create a service to run Sidecar.

Default value: ``false``

##### <a name="manage_query"></a>`manage_query`

Data type: `Boolean`

Whether to create a service to run Query.

Default value: ``false``

##### <a name="manage_query_frontend"></a>`manage_query_frontend`

Data type: `Boolean`

Whether to create a service to run Query Frontend.

Default value: ``false``

##### <a name="manage_rule"></a>`manage_rule`

Data type: `Boolean`

Whether to create a service to run Rule.

Default value: ``false``

##### <a name="manage_store"></a>`manage_store`

Data type: `Boolean`

Whether to create a service to run Store.

Default value: ``false``

##### <a name="manage_compact"></a>`manage_compact`

Data type: `Boolean`

Whether to create a service to run Compact.

Default value: ``false``

##### <a name="manage_receive"></a>`manage_receive`

Data type: `Boolean`

Whether to create a service to run Receiver.

Default value: ``false``

##### <a name="manage_tools_bucket_web"></a>`manage_tools_bucket_web`

Data type: `Boolean`

Whether to create a service to run Bucket Web interface.

Default value: ``false``

##### <a name="install_method"></a>`install_method`

Data type: `Enum['url', 'package', 'none']`

Installation method: url or package (only url is supported currently).

Default value: `'url'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent', 'latest']`

If package, then use this for package ensure default 'latest'.

Default value: `'latest'`

##### <a name="package_name"></a>`package_name`

Data type: `String`

Thanos package name - not available yet.

Default value: `'thanos'`

##### <a name="base_url"></a>`base_url`

Data type: `Stdlib::HTTPUrl`

Base URL for thanos.

Default value: `'https://github.com/thanos-io/thanos/releases/download'`

##### <a name="download_extension"></a>`download_extension`

Data type: `String`

Extension of Thanos binaries archive.

Default value: `'tar.gz'`

##### <a name="download_url"></a>`download_url`

Data type: `Optional[Stdlib::HTTPUrl]`

Complete URL corresponding to the Thanos release, default to undef.

Default value: ``undef``

##### <a name="base_dir"></a>`base_dir`

Data type: `Stdlib::Absolutepath`

Base directory where Thanos is extracted.

Default value: `'/opt'`

##### <a name="bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

Directory where binaries are located.

Default value: `'/usr/local/bin'`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

Directory where configuration are located.

Default value: `'/etc/thanos'`

##### <a name="purge_config_dir"></a>`purge_config_dir`

Data type: `Boolean`

Purge configuration directory.

Default value: ``true``

##### <a name="tsdb_path"></a>`tsdb_path`

Data type: `Stdlib::Absolutepath`

Data directory of TSDB.

Default value: `'/data'`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Whether to create user for thanos or rely on external code for that.

Default value: ``true``

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Whether to create user for thanos or rely on external code for that.

Default value: ``true``

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `'thanos'`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `'thanos'`

##### <a name="usershell"></a>`usershell`

Data type: `Stdlib::Absolutepath`

if requested, we create a user for thanos. The default shell is false. It can be overwritten to any valid path.

Default value: `'/bin/false'`

##### <a name="extra_groups"></a>`extra_groups`

Data type: `Array[String]`

Add other groups to the managed user.

Default value: `[]`

##### <a name="extract_command"></a>`extract_command`

Data type: `Optional[String]`

Custom command passed to the archive resource to extract the downloaded archive.

Default value: ``undef``

##### <a name="manage_storage_config"></a>`manage_storage_config`

Data type: `Boolean`

Whether to manage storage configuration file.

Default value: ``false``

##### <a name="storage_config_file"></a>`storage_config_file`

Data type: `Stdlib::Absolutepath`

Path to storage configuration file.

Default value: `"${config_dir}/storage.yaml"`

##### <a name="storage_config"></a>`storage_config`

Data type: `Hash[String, Data]`

Storage configuration.
   type: one of ['S3', 'GCS', 'AZURE', 'SWIFT', 'COS', 'ALIYUNOSS', 'FILESYSTEM']
   config: storage typed configuration in Hash[String, Data]

Default value: `{}`

##### <a name="manage_tracing_config"></a>`manage_tracing_config`

Data type: `Boolean`

Whether to manage tracing configuration file

Default value: ``false``

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to tracing configuration file.

Default value: ``undef``

##### <a name="tracing_config"></a>`tracing_config`

Data type: `Hash[String, Data]`

Tracing configuration.
   type: one of ['JAEGER', 'STACKDRIVER', 'ELASTIC_APM', 'LIGHTSTEP']
   config: tracing typed configuration in Hash[String, Data]

Default value: `{}`

##### <a name="manage_index_cache_config"></a>`manage_index_cache_config`

Data type: `Boolean`

Whether to manage index cache configuration file

Default value: ``false``

##### <a name="index_cache_config_file"></a>`index_cache_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to index cache configuration file.

Default value: ``undef``

##### <a name="index_cache_config"></a>`index_cache_config`

Data type: `Hash[String, Data]`

Index cache configuration.
   type: one of ['IN-MEMORY', 'MEMCACHED']
   config: index cache typed configuration in Hash[String, Data]

Default value: `{}`

### <a name="thanoscompact"></a>`thanos::compact`

This class install Compact as service to continuously compacts blocks in an object store bucket.

#### Examples

##### 

```puppet
include thanos::compact
```

#### Parameters

The following parameters are available in the `thanos::compact` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`data_dir`](#data_dir)
* [`objstore_config_file`](#objstore_config_file)
* [`consistency_delay`](#consistency_delay)
* [`retention_resolution_raw`](#retention_resolution_raw)
* [`retention_resolution_5m`](#retention_resolution_5m)
* [`retention_resolution_1h`](#retention_resolution_1h)
* [`wait`](#wait)
* [`wait_interval`](#wait_interval)
* [`downsampling_disable`](#downsampling_disable)
* [`block_sync_concurrency`](#block_sync_concurrency)
* [`block_viewer_global_sync_block_interval`](#block_viewer_global_sync_block_interval)
* [`compact_concurrency`](#compact_concurrency)
* [`delete_delay`](#delete_delay)
* [`selector_relabel_config_file`](#selector_relabel_config_file)
* [`web_external_prefix`](#web_external_prefix)
* [`web_prefix_header`](#web_prefix_header)
* [`bucket_web_label`](#bucket_web_label)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="data_dir"></a>`data_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Data directory in which to cache blocks and process compactions.

Default value: ``undef``

##### <a name="objstore_config_file"></a>`objstore_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains object store configuration. See format details: https://thanos.io/storage.md/#configuration

Default value: `$thanos::storage_config_file`

##### <a name="consistency_delay"></a>`consistency_delay`

Data type: `String`

Minimum age of fresh (non-compacted) blocks before they are being processed.
  Malformed blocks older than the maximum of consistency-delay and 30m0s will be removed.

Default value: `'30m'`

##### <a name="retention_resolution_raw"></a>`retention_resolution_raw`

Data type: `String`

How long to retain raw samples in bucket. 0d - disables this retention

Default value: `'0d'`

##### <a name="retention_resolution_5m"></a>`retention_resolution_5m`

Data type: `String`

How long to retain samples of resolution 1 (5 minutes) in bucket. 0d - disables this retention

Default value: `'0d'`

##### <a name="retention_resolution_1h"></a>`retention_resolution_1h`

Data type: `String`

How long to retain samples of resolution 2 (1 hour) in bucket. 0d - disables this retention

Default value: `'0d'`

##### <a name="wait"></a>`wait`

Data type: `Boolean`

Do not exit after all compactions have been processed and wait for new work.

Default value: ``false``

##### <a name="wait_interval"></a>`wait_interval`

Data type: `String`

Wait interval between consecutive compaction runs and bucket refreshes.
  Only works when --wait flag specified.

Default value: `'5m'`

##### <a name="downsampling_disable"></a>`downsampling_disable`

Data type: `Boolean`

Disables downsampling. This is not recommended as querying long time ranges without non-downsampled data is
  not efficient and useful e.g it is not possible to render all samples for a human eye anyway

Default value: ``false``

##### <a name="block_sync_concurrency"></a>`block_sync_concurrency`

Data type: `Integer`

Number of goroutines to use when syncing block metadata from object storage.

Default value: `20`

##### <a name="block_viewer_global_sync_block_interval"></a>`block_viewer_global_sync_block_interval`

Data type: `String`

Repeat interval for syncing the blocks between local and remote view for /global Block Viewer UI.

Default value: `'1m'`

##### <a name="compact_concurrency"></a>`compact_concurrency`

Data type: `Integer`

Number of goroutines to use when compacting groups.

Default value: `1`

##### <a name="delete_delay"></a>`delete_delay`

Data type: `String`

Time before a block marked for deletion is deleted from bucket.
  If delete-delay is non zero, blocks will be marked for deletion and compactor component will
  delete blocks marked for deletion from the bucket. If delete-delay is 0, blocks will be deleted straight away.
  Note that deleting blocks immediately can cause query failures, if store gateway still has the block loaded,
  or compactor is ignoring the deletion because it's compacting the block at the same time.

Default value: `'48h'`

##### <a name="selector_relabel_config_file"></a>`selector_relabel_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains relabeling configuration that allows selecting blocks.
  It follows native Prometheus relabel-config syntax.
  See format details: https://prometheus.io/docs/prometheus/latest/configuration/configuration/#relabel_config

Default value: ``undef``

##### <a name="web_external_prefix"></a>`web_external_prefix`

Data type: `Optional[String]`

Static prefix for all HTML links and redirect URLs in the bucket web UI interface.
  Actual endpoints are still served on / or the web.route-prefix.
  This allows thanos bucket web UI to be served behind a reverse proxy that strips a URL sub-path.

Default value: ``undef``

##### <a name="web_prefix_header"></a>`web_prefix_header`

Data type: `Optional[String]`

Name of HTTP request header used for dynamic prefixing of UI links and redirects.
  This option is ignored if web.external-prefix argument is set.
  Security risk: enable this option only if a reverse proxy in front of thanos is resetting the header.
  The --web.prefix-header=X-Forwarded-Prefix option can be useful, for example,
  if Thanos UI is served via Traefik reverse proxy with PathPrefixStrip option enabled,
  which sends the stripped prefix value in X-Forwarded-Prefix header. This allows thanos UI to be served on a sub-path.

Default value: ``undef``

##### <a name="bucket_web_label"></a>`bucket_web_label`

Data type: `Optional[String]`

Prometheus label to use as timeline title in the bucket web UI

Default value: ``undef``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

### <a name="thanosconfig"></a>`thanos::config`

This class install and manage configuration files like object store and tracing.

#### Examples

##### 

```puppet
include thanos::config
```

#### Parameters

The following parameters are available in the `thanos::config` class:

* [`manage_storage_config`](#manage_storage_config)
* [`storage_config_file`](#storage_config_file)
* [`storage_config`](#storage_config)
* [`manage_tracing_config`](#manage_tracing_config)
* [`tracing_config_file`](#tracing_config_file)
* [`tracing_config`](#tracing_config)
* [`manage_index_cache_config`](#manage_index_cache_config)
* [`index_cache_config_file`](#index_cache_config_file)
* [`index_cache_config`](#index_cache_config)

##### <a name="manage_storage_config"></a>`manage_storage_config`

Data type: `Boolean`

Whether to manage storage configuration file.

Default value: `$thanos::manage_storage_config`

##### <a name="storage_config_file"></a>`storage_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to storage configuration file.

Default value: `$thanos::storage_config_file`

##### <a name="storage_config"></a>`storage_config`

Data type: `Hash[String, Data]`

Storage configuration.
   type: one of ['S3', 'GCS', 'AZURE', 'SWIFT', 'COS', 'ALIYUNOSS', 'FILESYSTEM']
   config: storage typed configuration in Hash[String, Data]

Default value: `$thanos::storage_config`

##### <a name="manage_tracing_config"></a>`manage_tracing_config`

Data type: `Boolean`

Whether to manage tracing configuration file

Default value: `$thanos::manage_tracing_config`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to tracing configuration file.

Default value: `$thanos::tracing_config_file`

##### <a name="tracing_config"></a>`tracing_config`

Data type: `Hash[String, Data]`

Tracing configuration.
   type: one of ['JAEGER', 'STACKDRIVER', 'ELASTIC_APM', 'LIGHTSTEP']
   config: tracing typed configuration in Hash[String, Data]

Default value: `$thanos::tracing_config`

##### <a name="manage_index_cache_config"></a>`manage_index_cache_config`

Data type: `Boolean`

Whether to manage index cache configuration file

Default value: `$thanos::manage_index_cache_config`

##### <a name="index_cache_config_file"></a>`index_cache_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to index cache configuration file.

Default value: `$thanos::index_cache_config_file`

##### <a name="index_cache_config"></a>`index_cache_config`

Data type: `Hash[String, Data]`

Index cache configuration.
   type: one of ['IN-MEMORY', 'MEMCACHED']
   config: index cache typed configuration in Hash[String, Data]

Default value: `$thanos::index_cache_config`

### <a name="thanosinstall"></a>`thanos::install`

This class install Thanos requirements and binaries.

#### Examples

##### 

```puppet
include thanos::install
```

#### Parameters

The following parameters are available in the `thanos::install` class:

* [`version`](#version)
* [`package_name`](#package_name)
* [`os`](#os)
* [`real_arch`](#real_arch)
* [`package_ensure`](#package_ensure)
* [`install_method`](#install_method)
* [`download_extension`](#download_extension)
* [`download_url`](#download_url)
* [`extract_command`](#extract_command)
* [`base_dir`](#base_dir)
* [`bin_dir`](#bin_dir)
* [`config_dir`](#config_dir)
* [`purge_config_dir`](#purge_config_dir)
* [`notify_services`](#notify_services)
* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`user`](#user)
* [`group`](#group)
* [`usershell`](#usershell)
* [`extra_groups`](#extra_groups)

##### <a name="version"></a>`version`

Data type: `Pattern[/\d+\.\d+\.\d+/]`

Thanos release. See https://github.com/thanos-io/thanos/releases

Default value: `$thanos::version`

##### <a name="package_name"></a>`package_name`

Data type: `String`

Thanos package name - not available yet.

Default value: `$thanos::package_name`

##### <a name="os"></a>`os`

Data type: `String`

Operating system.

Default value: `$thanos::os`

##### <a name="real_arch"></a>`real_arch`

Data type: `String`

Architecture (amd64 or arm64).

Default value: `$thanos::real_arch`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent', 'latest']`

If package, then use this for package ensurel default 'latest'.

Default value: `$thanos::package_ensure`

##### <a name="install_method"></a>`install_method`

Data type: `Enum['url', 'package', 'none']`

Installation method: url or package (only url is supported currently).

Default value: `$thanos::install_method`

##### <a name="download_extension"></a>`download_extension`

Data type: `String`

Extension of Thanos binaries archive.

Default value: `$thanos::download_extension`

##### <a name="download_url"></a>`download_url`

Data type: `Stdlib::HTTPUrl`

Complete URL corresponding to the Prometheus release, default to undef.

Default value: `$thanos::real_download_url`

##### <a name="extract_command"></a>`extract_command`

Data type: `Optional[String]`

Custom command passed to the archive resource to extract the downloaded archive.

Default value: `$thanos::extract_command`

##### <a name="base_dir"></a>`base_dir`

Data type: `Stdlib::Absolutepath`

Base directory where Thanos is extracted.

Default value: `$thanos::base_dir`

##### <a name="bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

Directory where binaries are located.

Default value: `$thanos::bin_dir`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

Directory where configuration are located.

Default value: `$thanos::config_dir`

##### <a name="purge_config_dir"></a>`purge_config_dir`

Data type: `Boolean`

Purge configuration directory.

Default value: `$thanos::purge_config_dir`

##### <a name="notify_services"></a>`notify_services`

Data type: `Array[Type[Resource]]`

Services to notify when binaries changed.

Default value: `$thanos::notify_services`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Whether to create user for thanos or rely on external code for that.

Default value: `$thanos::manage_user`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Whether to create user for thanos or rely on external code for that.

Default value: `$thanos::manage_group`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="usershell"></a>`usershell`

Data type: `Stdlib::Absolutepath`

if requested, we create a user for thanos. The default shell is false. It can be overwritten to any valid path.

Default value: `$thanos::usershell`

##### <a name="extra_groups"></a>`extra_groups`

Data type: `Array[String]`

Add other groups to the managed user.

Default value: `$thanos::extra_groups`

### <a name="thanosquery"></a>`thanos::query`

This class install Query as service query node exposing PromQL enabled Query API with data retrieved from multiple store nodes.

#### Examples

##### 

```puppet
include thanos::query
```

#### Parameters

The following parameters are available in the `thanos::query` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`grpc_address`](#grpc_address)
* [`grpc_grace_period`](#grpc_grace_period)
* [`grpc_server_tls_cert`](#grpc_server_tls_cert)
* [`grpc_server_tls_key`](#grpc_server_tls_key)
* [`grpc_server_tls_client_ca`](#grpc_server_tls_client_ca)
* [`grpc_client_tls_secure`](#grpc_client_tls_secure)
* [`grpc_client_tls_cert`](#grpc_client_tls_cert)
* [`grpc_client_tls_key`](#grpc_client_tls_key)
* [`grpc_client_tls_ca`](#grpc_client_tls_ca)
* [`grpc_client_server_name`](#grpc_client_server_name)
* [`web_route_prefix`](#web_route_prefix)
* [`web_external_prefix`](#web_external_prefix)
* [`web_prefix_header`](#web_prefix_header)
* [`log_request_decision`](#log_request_decision)
* [`query_timeout`](#query_timeout)
* [`query_max_concurrent`](#query_max_concurrent)
* [`query_loopback_delta`](#query_loopback_delta)
* [`query_max_concurrent_select`](#query_max_concurrent_select)
* [`query_replica_label`](#query_replica_label)
* [`selector_labels`](#selector_labels)
* [`endpoints`](#endpoints)
* [`store_strict`](#store_strict)
* [`store_sd_files`](#store_sd_files)
* [`store_sd_interval`](#store_sd_interval)
* [`store_sd_dns_interval`](#store_sd_dns_interval)
* [`store_unhealthy_timeout`](#store_unhealthy_timeout)
* [`query_auto_downsampling`](#query_auto_downsampling)
* [`query_partial_response`](#query_partial_response)
* [`query_default_evaluation_interval`](#query_default_evaluation_interval)
* [`store_response_timeout`](#store_response_timeout)
* [`max_open_files`](#max_open_files)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="grpc_address"></a>`grpc_address`

Data type: `String`

Listen ip:port address for gRPC endpoints (StoreAPI). Make sure this address is routable from other components.

Default value: `'0.0.0.0:10901'`

##### <a name="grpc_grace_period"></a>`grpc_grace_period`

Data type: `String`

Time to wait after an interrupt received for GRPC Server.

Default value: `'2m'`

##### <a name="grpc_server_tls_cert"></a>`grpc_server_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificate for gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_key"></a>`grpc_server_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_client_ca"></a>`grpc_server_tls_client_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA to verify clients against. If no client CA is specified, there is no client verification on server side. (tls.NoClientCert)

Default value: ``undef``

##### <a name="grpc_client_tls_secure"></a>`grpc_client_tls_secure`

Data type: `Boolean`

Use TLS when talking to the gRPC server

Default value: ``false``

##### <a name="grpc_client_tls_cert"></a>`grpc_client_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificates to use to identify this client to the server

Default value: ``undef``

##### <a name="grpc_client_tls_key"></a>`grpc_client_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the client's certificate

Default value: ``undef``

##### <a name="grpc_client_tls_ca"></a>`grpc_client_tls_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA Certificates to use to verify gRPC servers

Default value: ``undef``

##### <a name="grpc_client_server_name"></a>`grpc_client_server_name`

Data type: `Optional[String]`

Server name to verify the hostname on the returned gRPC certificates. See https://tools.ietf.org/html/rfc4366#section-3.1

Default value: ``undef``

##### <a name="web_route_prefix"></a>`web_route_prefix`

Data type: `Optional[String]`

Prefix for API and UI endpoints. This allows thanos UI to be served on a sub-path.
  This option is analogous to --web.route-prefix of Promethus.

Default value: ``undef``

##### <a name="web_external_prefix"></a>`web_external_prefix`

Data type: `Optional[String]`

Static prefix for all HTML links and redirect URLs in the UI query web interface.
  Actual endpoints are still served on / or the web.route-prefix.
  This allows thanos UI to be served behind a reverse proxy that strips a URL sub-path.

Default value: ``undef``

##### <a name="web_prefix_header"></a>`web_prefix_header`

Data type: `Optional[String]`

Name of HTTP request header used for dynamic prefixing of UI links and redirects.
  This option is ignored if web.external-prefix argument is set.
  Security risk: enable this option only if a reverse proxy in front of thanos is resetting the header.
  The --web.prefix-header=X-Forwarded-Prefix option can be useful, for example,
  if Thanos UI is served via Traefik reverse proxy with PathPrefixStrip option enabled, which sends the stripped
  prefix value in X-Forwarded-Prefix header. This allows thanos UI to be served on a sub-path.

Default value: ``undef``

##### <a name="log_request_decision"></a>`log_request_decision`

Data type: `Optional[String]`

Request Logging for logging the start and end of requests. LogFinishCall is enabled by default.
  LogFinishCall : Logs the finish call of the requests.
  LogStartAndFinishCall : Logs the start and finish call of the requests.
  NoLogCall : Disable request logging.

Default value: ``undef``

##### <a name="query_timeout"></a>`query_timeout`

Data type: `String`

Maximum time to process query by query node.

Default value: `'2m'`

##### <a name="query_max_concurrent"></a>`query_max_concurrent`

Data type: `Integer`

Maximum number of queries processed concurrently by query node.

Default value: `20`

##### <a name="query_loopback_delta"></a>`query_loopback_delta`

Data type: `Optional[String]`

The maximum lookback duration for retrieving metrics during expression evaluations.
  PromQL always evaluates the query for the certain timestamp (query range timestamps are deduced by step).
  Since scrape intervals might be different, PromQL looks back for given amount of time to get latest sample.
  If it exceeds the maximum lookback delta it assumes series is stale and returns none (a gap).
  This is why lookback delta should be set to at least 2 times of the slowest scrape interval.
  If unset it will use the promql default of 5m.

Default value: ``undef``

##### <a name="query_max_concurrent_select"></a>`query_max_concurrent_select`

Data type: `Integer`

Maximum number of select requests made concurrently per a query.

Default value: `4`

##### <a name="query_replica_label"></a>`query_replica_label`

Data type: `Optional[String]`

Labels to treat as a replica indicator along which data is deduplicated.
  Still you will be able to query without deduplication using 'dedup=false' parameter.

Default value: ``undef``

##### <a name="selector_labels"></a>`selector_labels`

Data type: `Array[String]`

Query selector labels that will be exposed in info endpoint.

Default value: `[]`

##### <a name="endpoints"></a>`endpoints`

Data type: `Array[String]`

(Replace stores) Addresses of statically configured store API servers. The scheme may be prefixed with 'dns+' or 'dnssrv+'
  to detect store API servers through respective DNS lookups.

Default value: `[]`

##### <a name="store_strict"></a>`store_strict`

Data type: `Optional[String]`

Addresses of only statically configured store API servers that are always used, even if the health check fails.
  Useful if you have a caching layer on top.

Default value: ``undef``

##### <a name="store_sd_files"></a>`store_sd_files`

Data type: `Array[Stdlib::Absolutepath]`

Path to files that contain addresses of store API servers. The path can be a glob pattern.

Default value: `[]`

##### <a name="store_sd_interval"></a>`store_sd_interval`

Data type: `String`

Refresh interval to re-read file SD files. It is used as a resync fallback.

Default value: `'5m'`

##### <a name="store_sd_dns_interval"></a>`store_sd_dns_interval`

Data type: `String`

Interval between DNS resolutions.

Default value: `'30s'`

##### <a name="store_unhealthy_timeout"></a>`store_unhealthy_timeout`

Data type: `String`

Timeout before an unhealthy store is cleaned from the store UI page.

Default value: `'30s'`

##### <a name="query_auto_downsampling"></a>`query_auto_downsampling`

Data type: `Boolean`

Enable automatic adjustment (step / 5) to what source of data should be used in store gateways
  if no max_source_resolution param is specified.

Default value: ``false``

##### <a name="query_partial_response"></a>`query_partial_response`

Data type: `Boolean`

Enable partial response for queries if no partial_response param is specified. --no-query.partial-response for disabling.

Default value: ``false``

##### <a name="query_default_evaluation_interval"></a>`query_default_evaluation_interval`

Data type: `String`

Set default evaluation interval for sub queries.

Default value: `'1m'`

##### <a name="store_response_timeout"></a>`store_response_timeout`

Data type: `String`

If a Store doesn't send any data in this specified duration then a Store will be ignored and partial data will be
  returned if it's enabled. 0 disables timeout.

Default value: `'0ms'`

##### <a name="max_open_files"></a>`max_open_files`

Data type: `Optional[Integer]`

Define how many open files the service is able to use
In some cases, the default value (1024) needs to be increased

Default value: ``undef``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

### <a name="thanosquery_frontend"></a>`thanos::query_frontend`

This class install Query Frontend as service that can be put in front of Thanos Queriers to improve the read path.

#### Examples

##### 

```puppet
include thanos::query
```

#### Parameters

The following parameters are available in the `thanos::query_frontend` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`query_range_split_interval`](#query_range_split_interval)
* [`query_range_max_retries_per_request`](#query_range_max_retries_per_request)
* [`query_range_max_query_length`](#query_range_max_query_length)
* [`query_range_max_query_parrallelism`](#query_range_max_query_parrallelism)
* [`query_range_response_cache_max_freshness`](#query_range_response_cache_max_freshness)
* [`query_range_partial_response`](#query_range_partial_response)
* [`query_range_response_cache_config_file`](#query_range_response_cache_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`query_frontend_downstream_url`](#query_frontend_downstream_url)
* [`query_frontend_compress_responses`](#query_frontend_compress_responses)
* [`query_frontend_log_queries_longer_than`](#query_frontend_log_queries_longer_than)
* [`log_request_decision`](#log_request_decision)
* [`max_open_files`](#max_open_files)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="query_range_split_interval"></a>`query_range_split_interval`

Data type: `String`

Split queries by an interval and execute in parallel, 0 disables it.

Default value: `'24h'`

##### <a name="query_range_max_retries_per_request"></a>`query_range_max_retries_per_request`

Data type: `Integer`

Maximum number of retries for a single request; beyond this, the downstream error is returned.

Default value: `5`

##### <a name="query_range_max_query_length"></a>`query_range_max_query_length`

Data type: `Integer`

Limit the query time range (end - start time) in the query-frontend, 0 disables it.

Default value: `0`

##### <a name="query_range_max_query_parrallelism"></a>`query_range_max_query_parrallelism`

Data type: `Integer`

Maximum number of queries will be scheduled in parallel by the frontend.

Default value: `14`

##### <a name="query_range_response_cache_max_freshness"></a>`query_range_response_cache_max_freshness`

Data type: `String`

Most recent allowed cacheable result, to prevent caching very recent results that might still be in flux.

Default value: `'1m'`

##### <a name="query_range_partial_response"></a>`query_range_partial_response`

Data type: `Boolean`

Enable partial response for queries if no partial_response param is specified. --no-query-range.partial-response for disabling.

Default value: ``false``

##### <a name="query_range_response_cache_config_file"></a>`query_range_response_cache_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains response cache configuration.

Default value: ``undef``

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="query_frontend_downstream_url"></a>`query_frontend_downstream_url`

Data type: `Stdlib::HTTPUrl`

URL of downstream Prometheus Query compatible API.

Default value: `'http://localhost:9090'`

##### <a name="query_frontend_compress_responses"></a>`query_frontend_compress_responses`

Data type: `Boolean`

Compress HTTP responses.

Default value: ``false``

##### <a name="query_frontend_log_queries_longer_than"></a>`query_frontend_log_queries_longer_than`

Data type: `Integer`

Log queries that are slower than the specified duration. Set to 0 to disable. Set to < 0 to enable on all queries.

Default value: `0`

##### <a name="log_request_decision"></a>`log_request_decision`

Data type: `Optional[String]`

Request Logging for logging the start and end of requests. LogFinishCall is enabled by default.
  LogFinishCall : Logs the finish call of the requests.
  LogStartAndFinishCall : Logs the start and finish call of the requests.
  NoLogCall : Disable request logging.

Default value: ``undef``

##### <a name="max_open_files"></a>`max_open_files`

Data type: `Optional[Integer]`

Define how many open files the service is able to use
In some cases, the default value (1024) needs to be increased

Default value: ``undef``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

### <a name="thanosreceive"></a>`thanos::receive`

This class install Receiver as service that implements the Prometheus Remote Write API.

#### Examples

##### 

```puppet
include thanos::downsample
```

#### Parameters

The following parameters are available in the `thanos::receive` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`grpc_address`](#grpc_address)
* [`grpc_grace_period`](#grpc_grace_period)
* [`grpc_server_tls_cert`](#grpc_server_tls_cert)
* [`grpc_server_tls_key`](#grpc_server_tls_key)
* [`grpc_server_tls_client_ca`](#grpc_server_tls_client_ca)
* [`remote_write_address`](#remote_write_address)
* [`remote_write_server_tls_cert`](#remote_write_server_tls_cert)
* [`remote_write_server_tls_key`](#remote_write_server_tls_key)
* [`remote_write_server_tls_client_ca`](#remote_write_server_tls_client_ca)
* [`remote_write_client_tls_cert`](#remote_write_client_tls_cert)
* [`remote_write_client_tls_key`](#remote_write_client_tls_key)
* [`remote_write_client_tls_ca`](#remote_write_client_tls_ca)
* [`remote_write_client_server_name`](#remote_write_client_server_name)
* [`data_dir`](#data_dir)
* [`objstore_config_file`](#objstore_config_file)
* [`tsdb_retention`](#tsdb_retention)
* [`receive_hashrings_file`](#receive_hashrings_file)
* [`receive_hashrings_file_refresh_interval`](#receive_hashrings_file_refresh_interval)
* [`receive_local_endpoint`](#receive_local_endpoint)
* [`receive_tenant_header`](#receive_tenant_header)
* [`receive_default_tenant_id`](#receive_default_tenant_id)
* [`receive_tenant_label_name`](#receive_tenant_label_name)
* [`receive_replica_header`](#receive_replica_header)
* [`receive_replication_factor`](#receive_replication_factor)
* [`tsdb_wal_compression`](#tsdb_wal_compression)
* [`tsdb_no_lockfile`](#tsdb_no_lockfile)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="grpc_address"></a>`grpc_address`

Data type: `String`

Listen ip:port address for gRPC endpoints (StoreAPI). Make sure this address is routable from other components.

Default value: `'0.0.0.0:10901'`

##### <a name="grpc_grace_period"></a>`grpc_grace_period`

Data type: `String`

Time to wait after an interrupt received for GRPC Server.

Default value: `'2m'`

##### <a name="grpc_server_tls_cert"></a>`grpc_server_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificate for gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_key"></a>`grpc_server_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_client_ca"></a>`grpc_server_tls_client_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA to verify clients against. If no client CA is specified, there is no client verification on server side. (tls.NoClientCert)

Default value: ``undef``

##### <a name="remote_write_address"></a>`remote_write_address`

Data type: `String`

Address to listen on for remote write requests.

Default value: `'0.0.0.0:19291'`

##### <a name="remote_write_server_tls_cert"></a>`remote_write_server_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificate for HTTP server, leave blank to disable TLS.

Default value: ``undef``

##### <a name="remote_write_server_tls_key"></a>`remote_write_server_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the HTTP server, leave blank to disable TLS.

Default value: ``undef``

##### <a name="remote_write_server_tls_client_ca"></a>`remote_write_server_tls_client_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA to verify clients against. If no client CA is specified, there is no client verification on server side. (tls.NoClientCert)

Default value: ``undef``

##### <a name="remote_write_client_tls_cert"></a>`remote_write_client_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificates to use to identify this client to the server.

Default value: ``undef``

##### <a name="remote_write_client_tls_key"></a>`remote_write_client_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the client's certificate.

Default value: ``undef``

##### <a name="remote_write_client_tls_ca"></a>`remote_write_client_tls_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA Certificates to use to verify servers.

Default value: ``undef``

##### <a name="remote_write_client_server_name"></a>`remote_write_client_server_name`

Data type: `Optional[String]`

Server name to verify the hostname on the returned gRPC certificates. See https://tools.ietf.org/html/rfc4366#section-3.1

Default value: ``undef``

##### <a name="data_dir"></a>`data_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Data directory in which to cache blocks and process downsamplings.

Default value: ``undef``

##### <a name="objstore_config_file"></a>`objstore_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains object store configuration. See format details: https://thanos.io/storage.md/#configuration

Default value: `$thanos::storage_config_file`

##### <a name="tsdb_retention"></a>`tsdb_retention`

Data type: `String`

How long to retain raw samples on local storage. 0d - disables this retention.

Default value: `'15d'`

##### <a name="receive_hashrings_file"></a>`receive_hashrings_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to file that contains the hashring configuration.

Default value: ``undef``

##### <a name="receive_hashrings_file_refresh_interval"></a>`receive_hashrings_file_refresh_interval`

Data type: `String`

Refresh interval to re-read the hashring configuration file. (used as a fallback)

Default value: `'5m'`

##### <a name="receive_local_endpoint"></a>`receive_local_endpoint`

Data type: `Optional[String]`

Endpoint of local receive node. Used to identify the local node in the hashring configuration.

Default value: ``undef``

##### <a name="receive_tenant_header"></a>`receive_tenant_header`

Data type: `String`

HTTP header to determine tenant for write requests.

Default value: `'THANOS-TENANT'`

##### <a name="receive_default_tenant_id"></a>`receive_default_tenant_id`

Data type: `String`

HDefault tenant ID to use when none is provided via a header.

Default value: `'default-tenant'`

##### <a name="receive_tenant_label_name"></a>`receive_tenant_label_name`

Data type: `String`

Label name through which the tenant will be announced.

Default value: `'tenant_id'`

##### <a name="receive_replica_header"></a>`receive_replica_header`

Data type: `String`

HTTP header specifying the replica number of a write request.

Default value: `'THANOS-REPLICA'`

##### <a name="receive_replication_factor"></a>`receive_replication_factor`

Data type: `Integer`

How many times to replicate incoming write requests.

Default value: `1`

##### <a name="tsdb_wal_compression"></a>`tsdb_wal_compression`

Data type: `Boolean`

Compress the tsdb WAL.

Default value: ``false``

##### <a name="tsdb_no_lockfile"></a>`tsdb_no_lockfile`

Data type: `Boolean`

Do not create lockfile in TSDB data directory.
  In any case, the lockfiles will be deleted on next startup.

Default value: ``false``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

### <a name="thanosrule"></a>`thanos::rule`

This class install Rule as service ruler evaluating Prometheus rules against given Query nodes,
  exposing Store API and storing old blocks in bucket.

#### Examples

##### 

```puppet
include thanos::rule
```

#### Parameters

The following parameters are available in the `thanos::rule` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`grpc_address`](#grpc_address)
* [`grpc_grace_period`](#grpc_grace_period)
* [`grpc_server_tls_cert`](#grpc_server_tls_cert)
* [`grpc_server_tls_key`](#grpc_server_tls_key)
* [`grpc_server_tls_client_ca`](#grpc_server_tls_client_ca)
* [`labels`](#labels)
* [`data_dir`](#data_dir)
* [`rule_files`](#rule_files)
* [`resend_delay`](#resend_delay)
* [`eval_interval`](#eval_interval)
* [`tsdb_block_duration`](#tsdb_block_duration)
* [`tsdb_retention`](#tsdb_retention)
* [`tsdb_no_lockfile`](#tsdb_no_lockfile)
* [`tsdb_wal_compression`](#tsdb_wal_compression)
* [`alertmanagers_url`](#alertmanagers_url)
* [`alertmanagers_send_timeout`](#alertmanagers_send_timeout)
* [`alertmanagers_config_file`](#alertmanagers_config_file)
* [`alertmanagers_sd_dns_interval`](#alertmanagers_sd_dns_interval)
* [`alert_query_url`](#alert_query_url)
* [`alert_label_drop`](#alert_label_drop)
* [`web_route_prefix`](#web_route_prefix)
* [`web_external_prefix`](#web_external_prefix)
* [`web_prefix_header`](#web_prefix_header)
* [`log_request_decision`](#log_request_decision)
* [`objstore_config_file`](#objstore_config_file)
* [`queries`](#queries)
* [`query_config_file`](#query_config_file)
* [`query_sd_files`](#query_sd_files)
* [`query_sd_interval`](#query_sd_interval)
* [`query_sd_dns_interval`](#query_sd_dns_interval)
* [`max_open_files`](#max_open_files)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="grpc_address"></a>`grpc_address`

Data type: `String`

Listen ip:port address for gRPC endpoints (StoreAPI). Make sure this address is routable from other components.

Default value: `'0.0.0.0:10901'`

##### <a name="grpc_grace_period"></a>`grpc_grace_period`

Data type: `String`

Time to wait after an interrupt received for GRPC Server.

Default value: `'2m'`

##### <a name="grpc_server_tls_cert"></a>`grpc_server_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificate for gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_key"></a>`grpc_server_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_client_ca"></a>`grpc_server_tls_client_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA to verify clients against. If no client CA is specified,
  there is no client verification on server side. (tls.NoClientCert)

Default value: ``undef``

##### <a name="labels"></a>`labels`

Data type: `Array[String]`

Labels to be applied to all generated metrics. Similar to external labels for Prometheus,
  used to identify ruler and its blocks as unique source.

Default value: `[]`

##### <a name="data_dir"></a>`data_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Data directory.

Default value: ``undef``

##### <a name="rule_files"></a>`rule_files`

Data type: `Array[Stdlib::Absolutepath]`

Rule files that should be used by rule manager. Can be in glob format.

Default value: `[]`

##### <a name="resend_delay"></a>`resend_delay`

Data type: `String`

Minimum amount of time to wait before resending an alert to Alertmanager.

Default value: `'1m'`

##### <a name="eval_interval"></a>`eval_interval`

Data type: `String`

The default evaluation interval to use.

Default value: `'30s'`

##### <a name="tsdb_block_duration"></a>`tsdb_block_duration`

Data type: `String`

Block duration for TSDB block.

Default value: `'2h'`

##### <a name="tsdb_retention"></a>`tsdb_retention`

Data type: `String`

Block retention time on local disk.

Default value: `'48h'`

##### <a name="tsdb_no_lockfile"></a>`tsdb_no_lockfile`

Data type: `Boolean`

Do not create lockfile in TSDB data directory. In any case, the lockfiles will be deleted on next startup.

Default value: ``false``

##### <a name="tsdb_wal_compression"></a>`tsdb_wal_compression`

Data type: `Boolean`

Compress the tsdb WAL.

Default value: ``false``

##### <a name="alertmanagers_url"></a>`alertmanagers_url`

Data type: `Array[Stdlib::HTTPUrl]`

Alertmanager replica URLs to push firing alerts.
  Ruler claims success if push to at least one alertmanager from discovered succeeds.
  The scheme may be prefixed with 'dns+' or 'dnssrv+' to detect Alertmanager IPs through respective DNS lookups.
  The port defaults to 9093 or the SRV record's value.
  The URL path is used as a prefix for the regular Alertmanager API path.

Default value: `[]`

##### <a name="alertmanagers_send_timeout"></a>`alertmanagers_send_timeout`

Data type: `String`

Timeout for sending alerts to alertmanager

Default value: `'10s'`

##### <a name="alertmanagers_config_file"></a>`alertmanagers_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains alerting configuration.
See format details: https://thanos.io/components/rule.md/#configuration.
If defined, it takes precedence over the alertmanagers_url and alertmanagers_send_timeout options.

Default value: ``undef``

##### <a name="alertmanagers_sd_dns_interval"></a>`alertmanagers_sd_dns_interval`

Data type: `String`

Interval between DNS resolutions of Alertmanager hosts.

Default value: `'30s'`

##### <a name="alert_query_url"></a>`alert_query_url`

Data type: `Optional[Stdlib::HTTPUrl]`

The external Thanos Query URL that would be set in all alerts 'Source' field

Default value: ``undef``

##### <a name="alert_label_drop"></a>`alert_label_drop`

Data type: `Array[String]`

Labels by name to drop before sending to alertmanager. This allows alert to be deduplicated on replica label.
  Similar Prometheus alert relabelling

Default value: `[]`

##### <a name="web_route_prefix"></a>`web_route_prefix`

Data type: `Optional[String]`

Prefix for API and UI endpoints. This allows thanos UI to be served on a sub-path.
  This option is analogous to --web.route-prefix of Prometheus.

Default value: ``undef``

##### <a name="web_external_prefix"></a>`web_external_prefix`

Data type: `Optional[String]`

Static prefix for all HTML links and redirect URLs in the UI query web interface.
  Actual endpoints are still served on / or the web.route-prefix.
  This allows thanos UI to be served behind a reverse proxy that strips a URL sub-path.

Default value: ``undef``

##### <a name="web_prefix_header"></a>`web_prefix_header`

Data type: `Optional[String]`

Name of HTTP request header used for dynamic prefixing of UI links and redirects.
  This option is ignored if web.external-prefix argument is set.
  Security risk: enable this option only if a reverse proxy in front of thanos is resetting the header.
  The --web.prefix-header=X-Forwarded-Prefix option can be useful, for example,
  if Thanos UI is served via Traefik reverse proxy with PathPrefixStrip option enabled, hich sends the stripped
  prefix value in  X-Forwarded-Prefix header. This allows thanos UI to be served on a sub-path.

Default value: ``undef``

##### <a name="log_request_decision"></a>`log_request_decision`

Data type: `Optional[String]`

Request Logging for logging the start and end of requests. LogFinishCall is enabled by default.
  LogFinishCall : Logs the finish call of the requests.
  LogStartAndFinishCall : Logs the start and finish call of the requests.
  NoLogCall : Disable request logging.

Default value: ``undef``

##### <a name="objstore_config_file"></a>`objstore_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains object store configuration. See format details:
  https://thanos.io/storage.md/#configuration

Default value: ``undef``

##### <a name="queries"></a>`queries`

Data type: `Array[String]`

Addresses of statically configured query API servers. The scheme may be prefixed with 'dns+' or
  'dnssrv+' to detect query API servers through respective DNS lookups.

Default value: `[]`

##### <a name="query_config_file"></a>`query_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains query API servers configuration.
See format details: https://thanos.io/components/rule.md/#configuration.
If defined, it takes precedence over the queries and query.sd-files options.

Default value: ``undef``

##### <a name="query_sd_files"></a>`query_sd_files`

Data type: `Array[Stdlib::Absolutepath]`

Path to file that contain addresses of query peers. The path can be a glob pattern.

Default value: `[]`

##### <a name="query_sd_interval"></a>`query_sd_interval`

Data type: `String`

Refresh interval to re-read file SD files. (used as a fallback)

Default value: `'5m'`

##### <a name="query_sd_dns_interval"></a>`query_sd_dns_interval`

Data type: `String`

Interval between DNS resolutions.

Default value: `'30s'`

##### <a name="max_open_files"></a>`max_open_files`

Data type: `Optional[Integer]`

Define how many open files the service is able to use
In some cases, the default value (1024) needs to be increased

Default value: ``undef``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

### <a name="thanossidecar"></a>`thanos::sidecar`

This class install Sidecar as service sidecar for Prometheus server.

#### Examples

##### 

```puppet
include thanos::sidecar
```

#### Parameters

The following parameters are available in the `thanos::sidecar` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`grpc_address`](#grpc_address)
* [`grpc_grace_period`](#grpc_grace_period)
* [`grpc_server_tls_cert`](#grpc_server_tls_cert)
* [`grpc_server_tls_key`](#grpc_server_tls_key)
* [`grpc_server_tls_client_ca`](#grpc_server_tls_client_ca)
* [`prometheus_url`](#prometheus_url)
* [`prometheus_ready_timeout`](#prometheus_ready_timeout)
* [`tsdb_path`](#tsdb_path)
* [`reloader_config_file`](#reloader_config_file)
* [`reloader_config_envsubst_file`](#reloader_config_envsubst_file)
* [`reloader_rule_dirs`](#reloader_rule_dirs)
* [`reloader_watch_interval`](#reloader_watch_interval)
* [`reloader_retry_interval`](#reloader_retry_interval)
* [`objstore_config_file`](#objstore_config_file)
* [`shipper_upload_compacted`](#shipper_upload_compacted)
* [`min_time`](#min_time)
* [`max_open_files`](#max_open_files)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="grpc_address"></a>`grpc_address`

Data type: `String`

Listen ip:port address for gRPC endpoints (StoreAPI). Make sure this address is routable from other components.

Default value: `'0.0.0.0:10901'`

##### <a name="grpc_grace_period"></a>`grpc_grace_period`

Data type: `String`

Time to wait after an interrupt received for GRPC Server.

Default value: `'2m'`

##### <a name="grpc_server_tls_cert"></a>`grpc_server_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificate for gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_key"></a>`grpc_server_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_client_ca"></a>`grpc_server_tls_client_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA to verify clients against. If no client CA is specified, there is no client verification on server side. (tls.NoClientCert)

Default value: ``undef``

##### <a name="prometheus_url"></a>`prometheus_url`

Data type: `Stdlib::HTTPUrl`

URL at which to reach Prometheus's API. For better performance use local network.

Default value: `'http://localhost:9090'`

##### <a name="prometheus_ready_timeout"></a>`prometheus_ready_timeout`

Data type: `String`

Maximum time to wait for the Prometheus instance to start up

Default value: `'10m'`

##### <a name="tsdb_path"></a>`tsdb_path`

Data type: `Stdlib::Absolutepath`

Data directory of TSDB.

Default value: `$thanos::tsdb_path`

##### <a name="reloader_config_file"></a>`reloader_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Config file watched by the reloader.

Default value: ``undef``

##### <a name="reloader_config_envsubst_file"></a>`reloader_config_envsubst_file`

Data type: `Optional[Stdlib::Absolutepath]`

Output file for environment variable substituted config file.

Default value: ``undef``

##### <a name="reloader_rule_dirs"></a>`reloader_rule_dirs`

Data type: `Array[Stdlib::Absolutepath]`

Rule directories for the reloader to refresh.

Default value: `[]`

##### <a name="reloader_watch_interval"></a>`reloader_watch_interval`

Data type: `String`

Controls how often reloader re-reads config and rules.

Default value: `'3m'`

##### <a name="reloader_retry_interval"></a>`reloader_retry_interval`

Data type: `String`

Controls how often reloader retries config reload in case of error.

Default value: `'5s'`

##### <a name="objstore_config_file"></a>`objstore_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains object store configuration. See format details: https://thanos.io/storage.md/#configuration

Default value: `$thanos::storage_config_file`

##### <a name="shipper_upload_compacted"></a>`shipper_upload_compacted`

Data type: `Boolean`

If true sidecar will try to upload compacted blocks as well. Useful for migration purposes.
Works only if compaction is disabled on Prometheus. Do it once and then disable the flag when done.

Default value: ``false``

##### <a name="min_time"></a>`min_time`

Data type: `Optional[String]`

Start of time range limit to serve. Thanos sidecar will serve only metrics, which happened later than this value.
  Option can be a constant time in RFC3339 format or time duration relative to current time, such as -1d or 2h45m.
  Valid duration units are ms, s, m, h, d, w, y.

Default value: ``undef``

##### <a name="max_open_files"></a>`max_open_files`

Data type: `Optional[Integer]`

Define how many open files the service is able to use
In some cases, the default value (1024) needs to be increased

Default value: ``undef``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

### <a name="thanosstore"></a>`thanos::store`

This class install Store as service store node giving access to blocks in a bucket provider.
   Now supported GCS, S3, Azure, Swift and Tencent COS..

#### Examples

##### 

```puppet
include thanos::store
```

#### Parameters

The following parameters are available in the `thanos::store` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`grpc_address`](#grpc_address)
* [`grpc_grace_period`](#grpc_grace_period)
* [`grpc_server_tls_cert`](#grpc_server_tls_cert)
* [`grpc_server_tls_key`](#grpc_server_tls_key)
* [`grpc_server_tls_client_ca`](#grpc_server_tls_client_ca)
* [`data_dir`](#data_dir)
* [`index_cache_config_file`](#index_cache_config_file)
* [`index_cache_size`](#index_cache_size)
* [`chunck_pool_size`](#chunck_pool_size)
* [`store_grpc_series_sample_limit`](#store_grpc_series_sample_limit)
* [`store_grpc_series_max_concurrency`](#store_grpc_series_max_concurrency)
* [`objstore_config_file`](#objstore_config_file)
* [`sync_block_duration`](#sync_block_duration)
* [`block_sync_concurrency`](#block_sync_concurrency)
* [`min_time`](#min_time)
* [`max_time`](#max_time)
* [`selector_relabel_config_file`](#selector_relabel_config_file)
* [`consistency_delay`](#consistency_delay)
* [`ignore_deletion_marks_delay`](#ignore_deletion_marks_delay)
* [`web_external_prefix`](#web_external_prefix)
* [`web_prefix_header`](#web_prefix_header)
* [`max_open_files`](#max_open_files)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="grpc_address"></a>`grpc_address`

Data type: `String`

Listen ip:port address for gRPC endpoints (StoreAPI). Make sure this address is routable from other components.

Default value: `'0.0.0.0:10901'`

##### <a name="grpc_grace_period"></a>`grpc_grace_period`

Data type: `String`

Time to wait after an interrupt received for GRPC Server.

Default value: `'2m'`

##### <a name="grpc_server_tls_cert"></a>`grpc_server_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Certificate for gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_key"></a>`grpc_server_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

TLS Key for the gRPC server, leave blank to disable TLS

Default value: ``undef``

##### <a name="grpc_server_tls_client_ca"></a>`grpc_server_tls_client_ca`

Data type: `Optional[Stdlib::Absolutepath]`

TLS CA to verify clients against. If no client CA is specified, there is no client verification on server side. (tls.NoClientCert)

Default value: ``undef``

##### <a name="data_dir"></a>`data_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Data directory in which to cache remote blocks.

Default value: ``undef``

##### <a name="index_cache_config_file"></a>`index_cache_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains index cache configuration.
  See format details: https://thanos.io/components/store.md/#index-cache

Default value: ``undef``

##### <a name="index_cache_size"></a>`index_cache_size`

Data type: `String`

Maximum size of items held in the index cache.

Default value: `'250MB'`

##### <a name="chunck_pool_size"></a>`chunck_pool_size`

Data type: `String`

Maximum size of concurrently allocatable bytes for chunks.

Default value: `'2GB'`

##### <a name="store_grpc_series_sample_limit"></a>`store_grpc_series_sample_limit`

Data type: `Integer`

Maximum amount of samples returned via a single Series call. 0 means no limit.
  NOTE: for efficiency we take 120 as the number of samples in chunk (it cannot be bigger than that),
  so the actual number of samples might be lower, even
  though the maximum could be hit.

Default value: `0`

##### <a name="store_grpc_series_max_concurrency"></a>`store_grpc_series_max_concurrency`

Data type: `Integer`

Maximum number of concurrent Series calls.

Default value: `20`

##### <a name="objstore_config_file"></a>`objstore_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains object store configuration. See format details: https://thanos.io/storage.md/#configuration

Default value: `$thanos::storage_config_file`

##### <a name="sync_block_duration"></a>`sync_block_duration`

Data type: `String`

Repeat interval for syncing the blocks between local and remote view.

Default value: `'3m'`

##### <a name="block_sync_concurrency"></a>`block_sync_concurrency`

Data type: `Integer`

Number of goroutines to use when syncing blocks from object storage.

Default value: `20`

##### <a name="min_time"></a>`min_time`

Data type: `Optional[String]`

Start of time range limit to serve. Thanos Store will serve only metrics, which happened later than this value.
  Option can be a constant time in RFC3339 format or time duration relative to current time, such as -1d or 2h45m. Valid
  duration units are ms, s, m, h, d, w, y.

Default value: ``undef``

##### <a name="max_time"></a>`max_time`

Data type: `Optional[String]`

End of time range limit to serve. Thanos Store will serve only blocks, which happened eariler than this value.
  Option can be a constant time in RFC3339 format or time duration relative to current time, such as -1d or 2h45m. Valid
  duration units are ms, s, m, h, d, w, y.

Default value: ``undef``

##### <a name="selector_relabel_config_file"></a>`selector_relabel_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains relabeling configuration that allows selecting blocks.
  It follows native Prometheus relabel-config syntax.
  See format details: https://prometheus.io/docs/prometheus/latest/configuration/configuration/#relabel_config

Default value: ``undef``

##### <a name="consistency_delay"></a>`consistency_delay`

Data type: `String`

Minimum age of all blocks before they are being read.

Default value: `'30m'`

##### <a name="ignore_deletion_marks_delay"></a>`ignore_deletion_marks_delay`

Data type: `String`

Duration after which the blocks marked for deletion will be filtered out while fetching blocks.
  The idea of ignore-deletion-marks-delay is to ignore blocks that are marked for deletion with some delay.
  This ensures store can still serve blocks that are meant to be deleted but do not have a replacement yet.
  If delete-delay duration is provided to compactor or bucket verify component,
  it will upload deletion-mark.json file to mark after what duration the block should be deleted rather than
  deleting the block straight away. If delete-delay is non-zero for compactor or bucket verify component,
  ignore-deletion-marks-delay should be set to (delete-delay)/2 so that blocks marked for deletion are filtered out
  while fetching blocks before being deleted from bucket. Default is 24h, half of the default value for --delete-delay on compactor.

Default value: `'24h'`

##### <a name="web_external_prefix"></a>`web_external_prefix`

Data type: `Optional[String]`

Static prefix for all HTML links and redirect URLs in the UI query web interface.
  Actual endpoints are still served on / or the web.route-prefix.
  This allows thanos UI to be served behind a reverse proxy that strips a URL sub-path.

Default value: ``undef``

##### <a name="web_prefix_header"></a>`web_prefix_header`

Data type: `Optional[String]`

Name of HTTP request header used for dynamic prefixing of UI links and redirects.
  This option is ignored if web.external-prefix argument is set.
  Security risk: enable this option only if a reverse proxy in front of thanos is resetting the header.
  The --web.prefix-header=X-Forwarded-Prefix option can be useful, for example,
  if Thanos UI is served via Traefik reverse proxy with PathPrefixStrip option enabled, which sends the stripped
  prefix value in X-Forwarded-Prefix header. This allows thanos UI to be served on a sub-path.

Default value: ``undef``

##### <a name="max_open_files"></a>`max_open_files`

Data type: `Optional[Integer]`

Define how many open files the service is able to use
In some cases, the default value (1024) needs to be increased

Default value: ``undef``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

### <a name="thanostoolsbucket_web"></a>`thanos::tools::bucket_web`

This class install Web interface for remote storage bucket.

#### Examples

##### 

```puppet
include thanos::bucket_web
```

#### Parameters

The following parameters are available in the `thanos::tools::bucket_web` class:

* [`ensure`](#ensure)
* [`user`](#user)
* [`group`](#group)
* [`bin_path`](#bin_path)
* [`log_level`](#log_level)
* [`log_format`](#log_format)
* [`tracing_config_file`](#tracing_config_file)
* [`objstore_config_file`](#objstore_config_file)
* [`http_address`](#http_address)
* [`http_grace_period`](#http_grace_period)
* [`web_external_prefix`](#web_external_prefix)
* [`web_prefix_header`](#web_prefix_header)
* [`refresh`](#refresh)
* [`timeout`](#timeout)
* [`label`](#label)
* [`max_open_files`](#max_open_files)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from compact service.

Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

Default value: `$thanos::user`

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

Default value: `$thanos::group`

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

Default value: `$thanos::bin_path`

##### <a name="log_level"></a>`log_level`

Data type: `Thanos::Log_level`

Only log messages with the given severity or above. One of: [debug, info, warn, error, fatal]

Default value: `'info'`

##### <a name="log_format"></a>`log_format`

Data type: `Enum['logfmt', 'json']`

Output format of log messages. One of: [logfmt, json]

Default value: `'logfmt'`

##### <a name="tracing_config_file"></a>`tracing_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file with tracing configuration. See format details: https://thanos.io/tracing.md/#configuration

Default value: `$thanos::tracing_config_file`

##### <a name="objstore_config_file"></a>`objstore_config_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to YAML file that contains object store configuration. See format details: https://thanos.io/storage.md/#configuration

Default value: `$thanos::storage_config_file`

##### <a name="http_address"></a>`http_address`

Data type: `String`

Listen host:port for HTTP endpoints.

Default value: `'0.0.0.0:10902'`

##### <a name="http_grace_period"></a>`http_grace_period`

Data type: `String`

Time to wait after an interrupt received for HTTP Server.

Default value: `'2m'`

##### <a name="web_external_prefix"></a>`web_external_prefix`

Data type: `Optional[String]`

Static prefix for all HTML links and redirect URLs in the bucket web UI interface.
Actual endpoints are still served on / or the web.route-prefix.
This allows thanos bucket web UI to be served behind a reverse proxy that strips a URL sub-path.

Default value: ``undef``

##### <a name="web_prefix_header"></a>`web_prefix_header`

Data type: `Optional[String]`

Name of HTTP request header used for dynamic prefixing of UI links and redirects.
This option is ignored if web.external-prefix argument is set.
Security risk: enable this option only if a reverse proxy in front of thanos is resetting the header.
The --web.prefix-header=X-Forwarded-Prefix option can be useful, for example, if Thanos UI is served via Traefik
  reverse proxy with PathPrefixStrip option enabled, which sends the stripped prefix value in X-Forwarded-Prefix header.
This allows thanos UI to be served on a sub-path.

Default value: ``undef``

##### <a name="refresh"></a>`refresh`

Data type: `String`

Refresh interval to download metadata from remote storage

Default value: `'30m'`

##### <a name="timeout"></a>`timeout`

Data type: `String`

Timeout to download metadata from remote storage

Default value: `'5m'`

##### <a name="label"></a>`label`

Data type: `Optional[String]`

Prometheus label to use as timeline title

Default value: ``undef``

##### <a name="max_open_files"></a>`max_open_files`

Data type: `Optional[Integer]`

Define how many open files the service is able to use
In some cases, the default value (1024) needs to be increased

Default value: ``undef``

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

## Defined types

### <a name="thanosconfigindex_cache"></a>`thanos::config::index_cache`

Manage Index cache configuration file.

#### Examples

##### 

```puppet
thanos::config::index_cache { '/etc/thanos/index_cache.yaml':
  ensure => 'present',
  type   => 'IN-MEMORY',
  config => {
    max_size      => 0,
    max_item_size => 0,
  },
}
```

#### Parameters

The following parameters are available in the `thanos::config::index_cache` defined type:

* [`ensure`](#ensure)
* [`type`](#type)
* [`config`](#config)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from configuration file.

##### <a name="type"></a>`type`

Data type: `Thanos::Index_cache_type`

Type of Index cache.
  One of ['IN-MEMORY', 'MEMCACHED']

##### <a name="config"></a>`config`

Data type: `Hash[String, Data]`

Configuration to typed index cache.

### <a name="thanosconfigstorage"></a>`thanos::config::storage`

Manage Storage configuration file.

#### Examples

##### 

```puppet
thanos::config::storage { '/etc/thanos/storage.yaml':
  ensure => 'present',
  type   => 'FILESYSTEM',
  config => {
    directory => '/data',
  },
}
```

#### Parameters

The following parameters are available in the `thanos::config::storage` defined type:

* [`ensure`](#ensure)
* [`type`](#type)
* [`config`](#config)
* [`prefix`](#prefix)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from configuration file.

##### <a name="type"></a>`type`

Data type: `Thanos::Storage_type`

Type of Storage configurarion.
  One of ['S3', 'GCS', 'AZURE', 'SWIFT', 'COS', 'ALIYUNOSS', 'FILESYSTEM']

##### <a name="config"></a>`config`

Data type: `Hash[String, Data]`

Configuration to typed storage.

##### <a name="prefix"></a>`prefix`

Data type: `String`

Set the prefix for to be used on the storage

Default value: `''`

### <a name="thanosconfigtracing"></a>`thanos::config::tracing`

Manage Tracing configuration file

#### Examples

##### 

```puppet
thanos::config::tracing { '/etc/thanos/tracing.yaml':
  ensure => 'present',
  type   => 'JAEGER',
  config => {...},
}
```

#### Parameters

The following parameters are available in the `thanos::config::tracing` defined type:

* [`ensure`](#ensure)
* [`type`](#type)
* [`config`](#config)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State ensured from configuration file.

##### <a name="type"></a>`type`

Data type: `Thanos::Tracing_type`

Type of Tracing configurarion.
  One of ['JAEGER', 'STACKDRIVER', 'ELASTIC_APM', 'LIGHTSTEP']

##### <a name="config"></a>`config`

Data type: `Hash[String, Data]`

Configuration to typed tracing.

### <a name="thanosresourcesservice"></a>`thanos::resources::service`

This defined type create component's service.

#### Examples

##### 

```puppet
thanos::resources::service { 'component_name':
  ensure => 'running',
  bin_path => '/usr/local/bin/thanos',
}
```

#### Parameters

The following parameters are available in the `thanos::resources::service` defined type:

* [`ensure`](#ensure)
* [`bin_path`](#bin_path)
* [`user`](#user)
* [`group`](#group)
* [`max_open_files`](#max_open_files)
* [`params`](#params)
* [`extra_params`](#extra_params)

##### <a name="ensure"></a>`ensure`

Data type: `Variant[Stdlib::Ensure::Service, Enum['absent']]`

State ensured from component service.

##### <a name="bin_path"></a>`bin_path`

Data type: `Stdlib::Absolutepath`

Path where binary is located.

##### <a name="user"></a>`user`

Data type: `String`

User running thanos.

##### <a name="group"></a>`group`

Data type: `String`

Group under which thanos is running.

##### <a name="max_open_files"></a>`max_open_files`

Data type: `Optional[Integer]`

Define the maximum open files the service is allowed to use

Default value: ``undef``

##### <a name="params"></a>`params`

Data type: `Hash`

Parameters passed to the binary.

Default value: `{}`

##### <a name="extra_params"></a>`extra_params`

Data type: `Hash`

Parameters passed to the binary, ressently released in latest version of Thanos.

Default value: `{}`

## Data types

### <a name="thanosindex_cache_type"></a>`Thanos::Index_cache_type`

Thanos index cache type

Alias of

```puppet
Enum['IN-MEMORY', 'MEMCACHED']
```

### <a name="thanoslog_level"></a>`Thanos::Log_level`

Thanos Log Level type

Alias of

```puppet
Enum['debug', 'info', 'warn', 'error', 'fatal']
```

### <a name="thanosstorage_type"></a>`Thanos::Storage_type`

Thanos Storage type

Alias of

```puppet
Enum['S3', 'GCS', 'AZURE', 'SWIFT', 'COS', 'ALIYUNOSS', 'FILESYSTEM']
```

### <a name="thanostracing_type"></a>`Thanos::Tracing_type`

Thanos Tracing type

Alias of

```puppet
Enum['JAEGER', 'STACKDRIVER', 'ELASTIC_APM', 'LIGHTSTEP']
```

